@@ -10,4 +10,6 @@ globalVariables(c(".","k","Segment.Level","Segment.Child","Quant.Error",
                          "n.x", "n.y", "Quant.Error.y", "Scored.Quant.Error", "anomalyFlag", "Row.No", "x_coord", "y_coord",
                          "bp.x", "bp.y", "x", "y", "density","Cell.ID","Cell.Number","MapA.Cell.ID","MapA.Segment.Child","MapA.Segment.Level"
                          ,"MapA.Segment.Parent","MapC.Cell.ID","MapC.Cell.Path","MapC.Segment.Child","MapC.Segment.Level","MapC.Segment.Parent",
-                         "Row.Number","identified_outlier_cells", "Cell.ID.x", "Cell.ID.y", "Layer1.Cell.ID", "Layer2.Cell.ID", "Segment.Child.x", "Segment.Child.y", "Segment.Level.x", "Segment.Level.y", "Segment.Parent.x", "Segment.Parent.y", "identified_Novelty_cells", "mapC_cell_path"))
+                         "Row.Number","identified_outlier_cells", "Cell.ID.x", "Cell.ID.y", "Layer1.Cell.ID", "Layer2.Cell.ID", "Segment.Child.x",
+                        "Segment.Child.y", "Segment.Level.x", "Segment.Level.y", "Segment.Parent.x", "Segment.Parent.y", "identified_Novelty_cells",
+                        "mapC_cell_path", "results_df","hc","clusters","cluster_data","centroid_data"))
